@@ -1,6 +1,6 @@
 import pandas as pd
 
-from jutest.utils.choise import choice
+from jutest.utils.choice import choice
 from jutest.utils.display import display
 
 
