@@ -2,7 +2,7 @@ from collections import defaultdict
 
 import pandas as pd
 
-from jutest.utils.choise import choice
+from jutest.utils.choice import choice
 from jutest.utils.display import display
 
 
