@@ -1,7 +1,7 @@
 import pandas as pd
 
 from jutest.settings import NAN_VALUE
-from jutest.utils.choise import choice
+from jutest.utils.choice import choice
 from jutest.utils.display import display
 
 
